@@ -23,4 +23,6 @@ function buildGo() {
 buildGo ./lib/daemon
 
 buildGo ./lib/helper
-buildGo ./lib/open-ng
\ No newline at end of file
+buildGo ./lib/open-ng
+buildGo ./lib/flatpak-spawn-stub
+buildGo ./lib/prlimit-stub
\ No newline at end of file
